[−][src]Struct solana_vote_api::vote_state::VoteState
Fields
node_pubkey: Pubkeythe node that votes in this account
the signer for vote transactions
the signer for withdrawals
commission: u8fraction of std::u8::MAX that represents what part of a rewards payout should be given to this VoteAccount
votes: VecDeque<Lockout>root_slot: Option<u64>Methods
impl VoteState[src]
pub fn new(vote_init: &VoteInit) -> Self[src]
pub fn size_of() -> usize[src]
pub fn from(account: &Account) -> Option<VoteState>[src]
pub fn to(&self, account: &mut Account) -> Option<()>[src]
pub fn deserialize(input: &[u8]) -> Result<Self, InstructionError>[src]
pub fn serialize(&self, output: &mut [u8]) -> Result<(), InstructionError>[src]
pub fn credits_from(account: &Account) -> Option<u64>[src]
pub fn commission_split(&self, on: f64) -> (f64, f64, bool)[src]
returns commission split as (voter_portion, staker_portion, was_split) tuple
if commission calculation is 100% one way or other, indicate with false for was_split
pub fn process_vote(
&mut self,
vote: &Vote,
slot_hashes: &[SlotHash],
epoch: Epoch
) -> Result<(), VoteError>[src]
&mut self,
vote: &Vote,
slot_hashes: &[SlotHash],
epoch: Epoch
) -> Result<(), VoteError>
pub fn process_slot(&mut self, slot: Slot, epoch: Epoch)[src]
pub fn increment_credits(&mut self, epoch: Epoch)[src]
increment credits, record credits for last epoch if new epoch
pub fn process_vote_unchecked(&mut self, vote: &Vote)[src]
"unchecked" functions used by tests and Tower
pub fn process_slot_vote_unchecked(&mut self, slot: Slot)[src]
pub fn nth_recent_vote(&self, position: usize) -> Option<&Lockout>[src]
pub fn credits(&self) -> u64[src]
Number of "credits" owed to this account from the mining pool. Submit this VoteState to the Rewards program to trade credits for lamports.
pub fn epoch_credits(&self) -> impl Iterator<Item = &(Epoch, u64, u64)>[src]
Number of "credits" owed to this account from the mining pool on a per-epoch basis, starting from credits observed. Each tuple of (Epoch, u64, u64) is read as (epoch, credits, prev_credits), where credits for each epoch is credits - prev_credits; while redundant this makes calculating rewards over partial epochs nice and simple